
WuttaWeb
========

This package provides a "web layer" for custom apps.

It uses traditional server-side rendering with VueJS on the front-end.

Good documentation and 100% `test coverage`_ are priorities for this
project.

.. _test coverage: https://buildbot.rattailproject.org/coverage/wuttaweb/

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   glossary
   narr/index
   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
